paidiverpy.utils.static.html
============================

.. py:module:: paidiverpy.utils.static.html

.. autoapi-nested-parse::

   
   Static HTML files for paidiverpy.
















   ..
       !! processed by numpydoc !!


